==> kernel-1.1.18-sources.jar: voxeet/com/sdk/audio/SoundManager.java <==
package voxeet.com.sdk.audio;

import android.content.Context;
import android.support.annotation.NonNull;

import com.voxeet.android.media.MediaPowerManager;
import com.voxeet.android.media.audio.AudioRoute;

import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.HashMap;
import java.util.List;

import voxeet.com.sdk.utils.AudioType;
import voxeet.com.sdk.utils.SoundPool;
import voxeet.com.sdk.utils.Validate;

/**
 * Created by kevinleperf on 26/10/2018.
 */

public class SoundManager {

    private com.voxeet.android.media.audio.AudioManager mAudioManager;
    private MediaPowerManager mMediaPowerManager;
    private Context mContext;
    private android.media.AudioManager mSystemAudioService;
    private int mSoundMode;
    private int mSoundType = Integer.MIN_VALUE;
    private SoundPool _sound_pool;
    private HashMap<AudioType, String> mSounds;

    private boolean mEnable;

    private SoundManager() {
        enable();
    }

    public SoundManager(@NonNull Context context) {
        this();

        mSoundMode = android.media.AudioManager.STREAM_VOICE_CALL;

        mAudioManager = new com.voxeet.android.media.audio.AudioManager(context);
        mMediaPowerManager = new MediaPowerManager(context,
                currentRoute());

        mContext = context;
        mSystemAudioService = (android.media.AudioManager) mContext.getSystemService(Context.AUDIO_SERVICE);

        mSounds = new HashMap<>();
        configure();
    }

    /**
     * Get the current available routes
     *
     * @return a non null route
     */
    @NonNull
    public List<AudioRoute> getAvailableRoutes() {
        return mAudioManager.availableRoutes();
    }

    public AudioRoute currentRoute() {
        return mAudioManager.outputRoute();
    }

    public boolean setAudioRoute(@NonNull AudioRoute route) {
        Validate.runningOnUiThread();
        mAudioManager.setOutputRoute(route);
        return true;
    }

    public SoundManager setSpeakerMode(boolean isSpeaker) {
        mAudioManager.setSpeakerMode(isSpeaker);
        return this;
    }

    public boolean isSpeakerOn() {
        return AudioRoute.ROUTE_SPEAKER.equals(mAudioManager.outputRoute());
    }

    public SoundManager acquireLocks() {
        mMediaPowerManager.acquire();
        return this;
    }

    public SoundManager releaseLocks() {
        mMediaPowerManager.release();
        return this;
    }

    public SoundManager setInVoiceCallSoundType() {
        mAudioManager.forceVolumeControlStream(mSoundMode);
        return this;
    }

    public SoundManager resetDefaultSoundType() {
        mAudioManager.forceVolumeControlStream(mAudioManager.getDefaultSoundStreamType());
        return this;
    }

    private int getUiSoundsStreamType() {
        try {
            Method method = mSystemAudioService.getClass().getDeclaredMethod("getUiSoundsStreamType");

            Object result = method.invoke(mSystemAudioService);
            return (int) result;
        } catch (NoSuchMethodException e) {
            //e.printStackTrace();
        } catch (IllegalAccessException e) {
            //e.printStackTrace();
        } catch (InvocationTargetException e) {
            //e.printStackTrace();
        }
        return android.media.AudioManager.STREAM_SYSTEM;
    }

    private void forceVolumeControlStream(int type) {
        try {
            Method method = mSystemAudioService.getClass().getDeclaredMethod("forceVolumeControlStream", int.class);

            method.invoke(mSystemAudioService, type);
        } catch (NoSuchMethodException e) {
            //e.printStackTrace();
        } catch (IllegalAccessException e) {
            //e.printStackTrace();
        } catch (InvocationTargetException e) {
            //e.printStackTrace();
        }
    }

    public SoundManager abandonAudioFocusRequest() {
        mAudioManager.abandonAudioFocusRequest();
        return this;
    }

    public SoundManager requestAudioFocus() {
        mAudioManager.requestAudioFocus();
        return this;
    }

    private SoundPool getSoundPool() {
        if (_sound_pool == null) {
            _sound_pool = new SoundPool(mContext, mSoundMode);
        }
        return _sound_pool;
    }

    private void configure() {
        mSounds.put(AudioType.RING, "out.mp3");
        mSounds.put(AudioType.HANGUP, "leave.mp3");

        setSound(AudioType.RING, mSounds.get(AudioType.RING));
        setSound(AudioType.HANGUP, mSounds.get(AudioType.HANGUP));
    }

    public boolean setSound(@NonNull AudioType type, @NonNull String assetName) {
        return getSoundPool().release(type).setShortResource(type, assetName);
    }

    public SoundManager playSoundType(@NonNull AudioType type) {
        if (isEnabled()) {
            getSoundPool().playShortResource(type, mSounds.get(type));
        }
        return this;
    }

    public SoundManager playSoundTypeForce(@NonNull AudioType type) {
        getSoundPool().playShortResource(type, mSounds.get(type));
        return this;
    }

    public SoundManager stopSoundType(@NonNull AudioType audioType) {
        getSoundPool().stop(audioType);
        return this;
    }


    public SoundManager stop() {
        getSoundPool().stop();
        return this;
    }

    public SoundManager onConferencePreJoinedEvent() {
        mSoundType = getUiSoundsStreamType();
        forceVolumeControlStream(mSoundMode);
        return this;
    }

    public SoundManager onConferenceDestroyedPush() {
        if (Integer.MIN_VALUE != mSoundType) {
            forceVolumeControlStream(mSoundType);
        }
        return this;
    }

    public void enable() {
        mEnable = true;
    }

    public void disable() {
        mEnable = false;
    }

    private boolean isEnabled() {
        return mEnable;
    }
}

==> kernel-1.4.4-sources.jar: voxeet/com/sdk/audio/SoundManager.java <==
package voxeet.com.sdk.audio;

import android.content.Context;
import android.support.annotation.NonNull;

import com.voxeet.android.media.MediaPowerManager;
import com.voxeet.android.media.audio.AudioRoute;

import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.HashMap;
import java.util.List;

import voxeet.com.sdk.utils.AudioType;
import voxeet.com.sdk.utils.SoundPool;
import voxeet.com.sdk.utils.Validate;

/**
 * Created by kevinleperf on 26/10/2018.
 */

public class SoundManager {

    private com.voxeet.android.media.audio.AudioManager mAudioManager;
    private MediaPowerManager mMediaPowerManager;
    private Context mContext;
    private android.media.AudioManager mSystemAudioService;
    private int mSoundMode;
    private int mSoundType = Integer.MIN_VALUE;
    private SoundPool _sound_pool;
    private HashMap<AudioType, String> mSounds;

    private boolean mEnable;

    private SoundManager() {
        enable();
    }

    public SoundManager(@NonNull Context context) {
        this();

        mSoundMode = android.media.AudioManager.STREAM_VOICE_CALL;

        mAudioManager = new com.voxeet.android.media.audio.AudioManager(context);
        mMediaPowerManager = new MediaPowerManager(context,
                currentRoute());

        mContext = context;
        mSystemAudioService = (android.media.AudioManager) mContext.getSystemService(Context.AUDIO_SERVICE);

        mSounds = new HashMap<>();
        configure();
    }

    /**
     * Get the current available routes
     *
     * @return a non null route
     */
    @NonNull
    public List<AudioRoute> getAvailableRoutes() {
        return mAudioManager.availableRoutes();
    }

    public AudioRoute currentRoute() {
        return mAudioManager.outputRoute();
    }

    public boolean setAudioRoute(@NonNull AudioRoute route) {
        Validate.runningOnUiThread();
        mAudioManager.setOutputRoute(route);
        return true;
    }

    public SoundManager setSpeakerMode(boolean isSpeaker) {
        mAudioManager.setSpeakerMode(isSpeaker);
        return this;
    }

    public boolean isSpeakerOn() {
        return AudioRoute.ROUTE_SPEAKER.equals(mAudioManager.outputRoute());
    }

    public SoundManager acquireLocks() {
        mMediaPowerManager.acquire();
        return this;
    }

    public SoundManager releaseLocks() {
        mMediaPowerManager.release();
        return this;
    }

    public SoundManager setInVoiceCallSoundType() {
        mAudioManager.forceVolumeControlStream(mSoundMode);
        return this;
    }

    public SoundManager resetDefaultSoundType() {
        mAudioManager.forceVolumeControlStream(mAudioManager.getDefaultSoundStreamType());
        return this;
    }

    private int getUiSoundsStreamType() {
        try {
            Method method = mSystemAudioService.getClass().getDeclaredMethod("getUiSoundsStreamType");

            Object result = method.invoke(mSystemAudioService);
            return (int) result;
        } catch (NoSuchMethodException e) {
            //e.printStackTrace();
        } catch (IllegalAccessException e) {
            //e.printStackTrace();
        } catch (InvocationTargetException e) {
            //e.printStackTrace();
        }
        return android.media.AudioManager.STREAM_SYSTEM;
    }

    private void forceVolumeControlStream(int type) {
        try {
            Method method = mSystemAudioService.getClass().getDeclaredMethod("forceVolumeControlStream", int.class);

            method.invoke(mSystemAudioService, type);
        } catch (NoSuchMethodException e) {
            //e.printStackTrace();
        } catch (IllegalAccessException e) {
            //e.printStackTrace();
        } catch (InvocationTargetException e) {
            //e.printStackTrace();
        }
    }

    public SoundManager abandonAudioFocusRequest() {
        mAudioManager.abandonAudioFocusRequest();
        return this;
    }

    public SoundManager requestAudioFocus() {
        mAudioManager.requestAudioFocus();
        return this;
    }

    private SoundPool getSoundPool() {
        if (_sound_pool == null) {
            _sound_pool = new SoundPool(mContext, mSoundMode);
        }
        return _sound_pool;
    }

    private void configure() {
        mSounds.put(AudioType.RING, "out.mp3");
        mSounds.put(AudioType.HANGUP, "leave.mp3");

        setSound(AudioType.RING, mSounds.get(AudioType.RING));
        setSound(AudioType.HANGUP, mSounds.get(AudioType.HANGUP));
    }

    public boolean setSound(@NonNull AudioType type, @NonNull String assetName) {
        return getSoundPool().release(type).setShortResource(type, assetName);
    }

    public SoundManager playSoundType(@NonNull AudioType type) {
        if (isEnabled()) {
            getSoundPool().playShortResource(type, mSounds.get(type));
        }
        return this;
    }

    public SoundManager playSoundTypeForce(@NonNull AudioType type) {
        getSoundPool().playShortResource(type, mSounds.get(type));
        return this;
    }

    public SoundManager stopSoundType(@NonNull AudioType audioType) {
        getSoundPool().stop(audioType);
        return this;
    }


    public SoundManager stop() {
        getSoundPool().stop();
        return this;
    }

    public SoundManager onConferencePreJoinedEvent() {
        mSoundType = getUiSoundsStreamType();
        //forceVolumeControlStream(mSoundMode);
        requestAudioFocus();
        return this;
    }

    public SoundManager onConferenceDestroyedPush() {
        if (Integer.MIN_VALUE != mSoundType) {
            //forceVolumeControlStream(mSoundType);
        }
        abandonAudioFocusRequest();
        return this;
    }

    public void enable() {
        mEnable = true;
    }

    public void disable() {
        mEnable = false;
    }

    private boolean isEnabled() {
        return mEnable;
    }
}
